pub struct AutoChestSettings {
pub max_batch_size: i64,
}Fields
max_batch_size: i64Trait Implementations
Sourceimpl Clone for AutoChestSettings
impl Clone for AutoChestSettings
Sourcefn clone(&self) -> AutoChestSettings
fn clone(&self) -> AutoChestSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutoChestSettings
impl Debug for AutoChestSettings
Sourceimpl<'de> Deserialize<'de> for AutoChestSettings
impl<'de> Deserialize<'de> for AutoChestSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutoChestSettings
impl JsonSchema for AutoChestSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AutoChestSettings
impl Serialize for AutoChestSettings
Sourceimpl Tsify for AutoChestSettings
impl Tsify for AutoChestSettings